@@ -1,14 +1,13 @@
-package MBX::Alien::FLTK::Platform::Unix::Darwin;
+package inc::MBX::Alien::FLTK::Platform::Unix::Darwin;
 {
     use strict;
     use warnings;
     use Carp qw[];
     use Config qw[%Config];
-    use lib qw[.. ../../../../..];
-    use MBX::Alien::FLTK::Utility
-        qw[_o _a _dir _rel _abs find_h find_lib can_run];
-    use MBX::Alien::FLTK;
-    use base 'MBX::Alien::FLTK::Platform::Unix';
+    use inc::MBX::Alien::FLTK::Utility
+        qw[_o _a _rel _abs find_h find_lib can_run];
+    use inc::MBX::Alien::FLTK;
+    use base 'inc::MBX::Alien::FLTK::Platform::Unix';
     $|++;
 
     sub configure {
@@ -52,6 +51,6 @@ Creative Commons Attribution-Share Alike 3.0 License. See
 http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
 clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 
-=for git $Id: Darwin.pm f70fb16 2009-11-02 19:42:51Z sanko@cpan.org $
+=for git $Id: Darwin.pm dfa6aa4 2010-01-16 21:12:51Z sanko@cpan.org $
 
 =cut
